@@ -39,8 +39,6 @@ class Feedback:
         else:
             try:
                 for sub in self._subscribers:
-
-
                     if function == sub[CONF_FUNCTION] and id == sub[CONF_ID]:
                         driver_states = self._data[function][sub.get(CONF_ID)]
 
@@ -51,10 +49,10 @@ class Feedback:
                 _LOGGER.error(traceback.format_exc())
 
     async def handle_temp_subscribtion(self , id: int , pin: int):
-        pass
         for sub in self._temp_subscribers:
             if id == sub[CONF_ID] and pin == sub[CONF_PIN]:
-                await sub[CONF_PTR](self._data.temps).get(id, {}).get(pin, 0)
+                data = self._data.temps.get(id, {}).get(pin)
+                await sub[CONF_PTR](data)
 
 
     async def input_data(self , line):
@@ -85,7 +83,8 @@ class Feedback:
                 await self.callback() 
 
         except Exception as e:
-            _LOGGER.error(f"ERROR parsing data: {e}")
+            _LOGGER.error(f"ERROR parsing data: {e} (type: {type(e)})")
+            _LOGGER.error(traceback.format_exc())
 
     def subscribe(self , conf: dict):
         self._subscribers.append(conf)
